@@ -142,6 +142,10 @@ class ActionCollection:
         self.action_slice_blocks.setIcon(IconCollection.get('flash_on.svg'))
         self.action_slice_blocks.setShortcut('Ctrl+B')
 
+        self.action_xsection = QAction('&Cross-section', parent)
+        self.action_xsection.setIcon(IconCollection.get('flash_on.svg'))
+        self.action_xsection.setShortcut('Ctrl+Shift+S')
+
         self.action_viewer_properties = QAction('&Viewer properties', parent)
         self.action_viewer_properties.setIcon(IconCollection.get('compact_camera.svg'))
         self.action_viewer_properties.setShortcut('Ctrl+C')
