@@ -33,6 +33,7 @@ from .drawables.meshgl import MeshGL
 from .drawables.pointgl import PointGL
 from .drawables.tubegl import TubeGL
 from .drawables.textgl import TextGL
+from .drawables.gridgl import GridGL
 
 from .drawablefactory import DrawableFactory
 from .fpscounter import FPSCounter
@@ -131,7 +132,7 @@ class IntegrableViewer(QOpenGLWidget):
         self.initialize()
 
     def initialize(self) -> None:
-        # Axis/Background
+        # Orientation-Axis/Background
         self.register_drawable(self.factory.axis(), self.post_collection)
         self.register_drawable(self.factory.background(), self.pre_collection)
 
@@ -151,6 +152,80 @@ class IntegrableViewer(QOpenGLWidget):
         # FPSCounter
         self.fps_counter.add_callback(self.signal_fps_updated.emit)
 
+    """
+    Internal methods
+    """
+    def initializeGL(self) -> None:
+        glClearColor(0.0, 0.0, 0.0, 1.0)
+        glEnable(GL_VERTEX_PROGRAM_POINT_SIZE)
+        glEnable(GL_POINT_SPRITE)
+        glDisable(GL_CULL_FACE)
+        glEnable(GL_DEPTH_TEST)
+        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
+
+        # Initialize collections
+        self.pre_collection.initialize()
+        self.drawable_collection.initialize()
+        self.post_collection.initialize()
+
+    def paintGL(self) -> None:
+        # Clear screen
+        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
+
+        self.world.setToIdentity()
+        self.camera.setToIdentity()
+
+        # Translate by rotation center (world position)
+        self.world.translate(*self.rotation_center)
+
+        # Allow rotation of the world
+        self.world.rotate(self.rotation_angle[0], 1.0, 0.0, 0.0)
+        self.world.rotate(self.rotation_angle[1], 0.0, 1.0, 0.0)
+        self.world.rotate(self.rotation_angle[2], 0.0, 0.0, 1.0)
+
+        # Restore world
+        self.world.translate(*-self.rotation_center)
+
+        # Translate the camera
+        self.camera.translate(*-self.camera_position)
+
+        # Propagate common uniform values (programs lacking the uniform will ignore the command)
+        for collection in [self.pre_collection, self.drawable_collection, self.post_collection]:
+            # MVP matrices
+            collection.update_uniform('proj_matrix', self.proj)
+            collection.update_uniform('model_view_matrix', self.camera * self.world)
+
+            # Viewport values (with DPI awareness)
+            collection.update_uniform('viewport', *self.viewport)
+
+            # Update common uniforms (programs lacking the uniform will ignore the command)
+            collection.update_uniform('plane_origin', *self.last_cross_origin)
+            collection.update_uniform('plane_normal', *self.last_cross_normal)
+
+        # Draw every GLDrawable (meshes, blocks, points, etc)
+        glEnable(GL_BLEND)
+        self.pre_collection.draw()
+        self.drawable_collection.draw()
+        self.post_collection.draw()
+
+        # Tick FPS counter
+        self.fps_counter.tick()
+
+    def resizeGL(self, w: float, h: float) -> None:
+        self.proj.setToIdentity()
+
+        if self.current_projection == 'Perspective':
+            self.proj.perspective(self.fov, self.aspect, 1.0, 100000.0)
+        else:  # if self.current_projection == 'Orthographic':
+            z = self.off_center[2] * 0.65
+            self.proj.ortho(-z, z, -z / self.aspect, z / self.aspect, 0.0, 100000.0)
+
+    def recreate(self) -> None:
+        self.pre_collection.recreate()
+        self.drawable_collection.recreate()
+        self.post_collection.recreate()
+        self.update()
+
     """
     Properties
     """
@@ -174,6 +249,15 @@ class IntegrableViewer(QOpenGLWidget):
     def off_center(self) -> np.ndarray:
         return self.camera_position - self.rotation_center
 
+    @property
+    def aspect(self) -> float:
+        return 1.0 * self.width() / self.height()
+
+    @property
+    def viewport(self) -> iter:
+        return [float(self.devicePixelRatio() * self.width()),
+                float(self.devicePixelRatio() * self.height())]
+
     """
     Camera movements/rotations
     """
@@ -190,19 +274,19 @@ class IntegrableViewer(QOpenGLWidget):
         return self._rotation_center
 
     @camera_position.setter
-    def camera_position(self, pos: list) -> None:
-        self._camera_position = np.asarray(pos)
-        self.signal_camera_translated.emit(pos)
+    def camera_position(self, value: iter) -> None:
+        self._camera_position = np.asarray(value)
+        self.signal_camera_translated.emit(value)
 
     @rotation_angle.setter
-    def rotation_angle(self, rot: list) -> None:
-        self._rotation_angle = np.asarray(rot)
-        self.signal_camera_rotated.emit(rot)
+    def rotation_angle(self, value: iter) -> None:
+        self._rotation_angle = np.asarray(value)
+        self.signal_camera_rotated.emit(value)
 
     @rotation_center.setter
-    def rotation_center(self, center: list) -> None:
-        self._rotation_center = np.asarray(center)
-        self.signal_center_translated.emit(center)
+    def rotation_center(self, value: iter) -> None:
+        self._rotation_center = np.asarray(value)
+        self.signal_center_translated.emit(value)
 
     """
     API for partial camera movements/rotations
@@ -303,11 +387,13 @@ class IntegrableViewer(QOpenGLWidget):
     def perspective_projection(self) -> None:
         self.current_projection = 'Perspective'
         self.signal_projection_updated.emit(self.current_projection)
+        self.resizeGL(self.width(), self.height())
         self.update()
 
     def orthographic_projection(self) -> None:
         self.current_projection = 'Orthographic'
         self.signal_projection_updated.emit(self.current_projection)
+        self.resizeGL(self.width(), self.height())
         self.update()
 
     """
@@ -352,6 +438,9 @@ class IntegrableViewer(QOpenGLWidget):
     def text(self, *args, **kwargs) -> TextGL:
         return self.register_drawable(self.factory.text(*args, **kwargs))
 
+    def grid(self, *args, **kwargs) -> GridGL:
+        return self.register_drawable(self.factory.grid(*args, **kwargs))
+
     """
     Load methods by path
     """
@@ -445,7 +534,7 @@ class IntegrableViewer(QOpenGLWidget):
 
     def update_drawable(self, _id: int) -> None:
         self.makeCurrent()
-        self.get_drawable(_id).setup_attributes()
+        self.get_drawable(_id).reload()
         self.recreate()
 
     def delete(self, _id: int) -> None:
@@ -514,18 +603,17 @@ class IntegrableViewer(QOpenGLWidget):
 
         # Put the camera in a position that allow us to see between the boundaries.
         md = np.max(np.diff([min_bound, max_bound], axis=0))
-        aspect = self.width() / self.height()
         fov_rad = self.fov * np.pi / 180.0
 
         # In perspective projection, we need a clever trigonometric calculation.
         if self.current_projection == 'Perspective':
             dist = (md / np.tan(fov_rad / 2) + md) / 2.0
-            z_shift = dist * max(1.0, 1.0 / aspect)
+            z_shift = dist * max(1.0, 1.0 / self.aspect)
 
         # But in orthographic projection, it's more direct.
         else:
             dist = md / 2
-            z_shift = dist * max(1.0, aspect)
+            z_shift = dist * max(1.0, self.aspect)
 
         camera_shift = center + np.array([0.0, 0.0, 1.1 * z_shift])
         self.set_camera_position(camera_shift)
@@ -553,86 +641,6 @@ class IntegrableViewer(QOpenGLWidget):
 
         return min_all, max_all
 
-    """
-    Internal methods
-    """
-    def initializeGL(self) -> None:
-        glClearColor(0.0, 0.0, 0.0, 1.0)
-        glEnable(GL_VERTEX_PROGRAM_POINT_SIZE)
-        glEnable(GL_POINT_SPRITE)
-        glDisable(GL_CULL_FACE)
-        glEnable(GL_DEPTH_TEST)
-        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
-
-        # Initialize collections
-        self.pre_collection.initialize()
-        self.drawable_collection.initialize()
-        self.post_collection.initialize()
-
-    def paintGL(self) -> None:
-        # Clear screen
-        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
-
-        self.world.setToIdentity()
-        self.camera.setToIdentity()
-        self.proj.setToIdentity()
-
-        # Translate by rotation center (world position)
-        self.world.translate(*self.rotation_center)
-
-        # Allow rotation of the world
-        self.world.rotate(self.rotation_angle[0], 1.0, 0.0, 0.0)
-        self.world.rotate(self.rotation_angle[1], 0.0, 1.0, 0.0)
-        self.world.rotate(self.rotation_angle[2], 0.0, 0.0, 1.0)
-
-        # Restore world
-        self.world.translate(*-self.rotation_center)
-
-        # Translate the camera
-        self.camera.translate(*-self.camera_position)
-
-        # Project (Perspective/Orthographic)
-        self.resizeGL(self.width(), self.height())
-
-        # Propagate common uniform values (programs lacking the uniform will ignore the command)
-        for collection in [self.pre_collection, self.drawable_collection, self.post_collection]:
-            # MVP matrices
-            collection.update_uniform('proj_matrix', self.proj)
-            collection.update_uniform('model_view_matrix', self.camera * self.world)
-
-            # Viewport values (with DPI awareness)
-            viewport = [float(self.devicePixelRatio() * self.width()),
-                        float(self.devicePixelRatio() * self.height())]
-            collection.update_uniform('viewport', *viewport)
-
-            # Update common uniforms (programs lacking the uniform will ignore the command)
-            collection.update_uniform('plane_origin', *self.last_cross_origin)
-            collection.update_uniform('plane_normal', *self.last_cross_normal)
-
-        # Draw every GLDrawable (meshes, blocks, points, etc)
-        glEnable(GL_BLEND)
-        self.pre_collection.draw()
-        self.drawable_collection.draw()
-        self.post_collection.draw()
-
-        # Tick FPS counter
-        self.fps_counter.tick()
-
-    def resizeGL(self, w: float, h: float) -> None:
-        aspect = w / h
-
-        if self.current_projection == 'Perspective':
-            self.proj.perspective(self.fov, aspect, 1.0, 100000.0)
-        else:  # if self.current_projection == 'Orthographic':
-            z = self.off_center[2]
-            self.proj.ortho(-z, z, -z / aspect, z / aspect, 0.0, 100000.0)
-
-    def recreate(self) -> None:
-        self.pre_collection.recreate()
-        self.drawable_collection.recreate()
-        self.post_collection.recreate()
-        self.update()
-
     """
     Utilities
     """
@@ -677,17 +685,11 @@ class IntegrableViewer(QOpenGLWidget):
 
     def ray_from_click(self, x: float, y: float, z: float) -> np.ndarray:
         # Perspective projection is straightforward
-        def perspective_ray() -> np.ndarray:
+        if self.current_projection == 'Perspective':
             return self.unproject(*self.screen_to_ndc(x, y, z))
 
         # Orthographic projection "forces" a click in the center (normalized to [-1.0, +1.0])
-        def orthographic_ray() -> np.ndarray:
-            return self.unproject(0.0, 0.0, 0.0)
-
-        if self.current_projection == 'Perspective':
-            return perspective_ray()
-
-        return orthographic_ray()
+        return self.unproject(0.0, 0.0, 0.0)
 
     def origin_from_click(self, x: float, y: float, z: float) -> np.ndarray:
         # Perspective projection is straightforward
@@ -703,8 +705,7 @@ class IntegrableViewer(QOpenGLWidget):
         # we need to trick the origin calculation.
         def orthographic_origin() -> np.ndarray:
             ndc = self.screen_to_ndc(x, y, z)
-            aspect = self.width() / self.height()
-            aspect_bias = np.array([1.0, 1.0 / aspect, 0.0])
+            aspect_bias = np.array([1.0, 1.0 / self.aspect, 0.0])
 
             # The idea is to strategically move the camera by an offset, so that
             # clicking anywhere in the screen will give us the same result as
@@ -725,18 +726,12 @@ class IntegrableViewer(QOpenGLWidget):
 
     def get_normal(self, origin_list, ray_list: list) -> np.ndarray:
         # Perspective: Same origins, different rays
-        def perspective_normal() -> np.ndarray:
+        if self.current_projection == 'Perspective':
             return utils.normalize(np.cross(*ray_list))
 
-        def orthographic_normal() -> np.ndarray:
-            # Orthographic: Same rays, different origins
-            origin_diff = np.diff(origin_list, axis=0)[0]
-            return utils.normalize(np.cross(ray_list[0], origin_diff))
-
-        if self.current_projection == 'Perspective':
-            return perspective_normal()
-
-        return orthographic_normal()
+        # Orthographic: Same rays, different origins
+        origin_diff = np.diff(origin_list, axis=0)[0]
+        return utils.normalize(np.cross(ray_list[0], origin_diff))
 
     @staticmethod
     def angles_from_vectors(normal: np.ndarray, up: np.ndarray) -> np.ndarray:
@@ -767,19 +762,23 @@ class IntegrableViewer(QOpenGLWidget):
 
         self.set_rotation_angle(self.angles_from_vectors(normal, up))
 
-    def generate_slice_description(self, origin_list: list, ray_list: list) -> None:
+    def generate_slice_description(self, origin_list: list, ray_list: list) -> dict:
         # A plane is created from `origin` and `ray_list`.
         # In perspective projection, the origin is the same.
         origin = origin_list[0]
         normal = self.get_normal(origin_list, ray_list)
         up = utils.normalize(np.cross(ray_list[0], normal))
 
-        # Emit description of the slice
-        self.signal_slice_description.emit({
+        response = {
             'origin': origin,
             'normal': normal,
             'up': up,
-        })
+        }
+
+        # Emit description of the slice
+        self.signal_slice_description.emit(response)
+
+        return response
 
     def slice_meshes(self, origin: np.ndarray, normal: np.ndarray, include_hidden: bool = False) -> list:
         # By default, slice only visible meshes
@@ -814,11 +813,15 @@ class IntegrableViewer(QOpenGLWidget):
         self.signal_lines_clicked.emit(lines)
         self.signal_elements_detected.emit(results)
 
-    def measure_from_rays(self, origin_list: list, ray_list: list) -> None:
+        return results
+
+    def measure_from_rays(self, origin_list: list, ray_list: list) -> dict:
         meshes = list(filter(lambda m: m.is_visible, self.get_all_meshes()))
 
-        results = self.model.measure_from_rays(origin_list, ray_list, meshes)
-        self.signal_mesh_distances.emit(results)
+        response = self.model.measure_from_rays(origin_list, ray_list, meshes)
+        self.signal_mesh_distances.emit(response)
+
+        return response
 
     def cross_section(self, origin: np.ndarray, normal: np.ndarray) -> None:
         # Uniforms in cross-section are always auto-updated in self.paintGL()
